summaryrefslogtreecommitdiffstats
path: root/kdeui/kiconview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdeui/kiconview.cpp')
-rw-r--r--kdeui/kiconview.cpp34
1 files changed, 17 insertions, 17 deletions
diff --git a/kdeui/kiconview.cpp b/kdeui/kiconview.cpp
index 102fb3cc4..13b6183ad 100644
--- a/kdeui/kiconview.cpp
+++ b/kdeui/kiconview.cpp
@@ -49,7 +49,7 @@ public:
KIconView::Mode mode;
bool doAutoSelect;
TQFontMetrics *fm;
- TQPixmapCache tqmaskCache;
+ TQPixmapCache maskCache;
int textHeight;
TQIconViewItem *dragHoldItem;
TQTimer dragHoldTimer;
@@ -186,7 +186,7 @@ void KIconView::slotAutoSelect()
bool update = viewport()->isUpdatesEnabled();
viewport()->setUpdatesEnabled( false );
- //Calculate the smallest rectangle that tqcontains the current Item
+ //Calculate the smallest rectangle that contains the current Item
//and the one that got the autoselect event
TQRect r;
TQRect redraw;
@@ -217,7 +217,7 @@ void KIconView::slotAutoSelect()
blockSignals( block );
viewport()->setUpdatesEnabled( update );
- tqrepaintContents( redraw, false );
+ repaintContents( redraw, false );
emit selectionChanged();
@@ -258,7 +258,7 @@ void KIconView::emitExecute( TQIconViewItem *item, const TQPoint &pos )
void KIconView::updateDragHoldItem( TQDropEvent *e )
{
- TQIconViewItem *item = tqfindItem( e->pos() );
+ TQIconViewItem *item = findItem( e->pos() );
if ( d->dragHoldItem != item)
{
@@ -307,7 +307,7 @@ void KIconView::contentsMouseDoubleClickEvent ( TQMouseEvent * e )
{
TQIconView::contentsMouseDoubleClickEvent( e );
- TQIconViewItem* item = tqfindItem( e->pos() );
+ TQIconViewItem* item = findItem( e->pos() );
if( item ) {
if( (e->button() == LeftButton) && !m_bUseSingle )
@@ -417,10 +417,10 @@ TQFontMetrics *KIconView::itemFontMetrics() const
TQPixmap KIconView::selectedIconPixmap( TQPixmap *pix, const TQColor &col ) const
{
TQPixmap m;
- if ( d->tqmaskCache.tqfind( TQString::number( pix->serialNumber() ), m ) )
+ if ( d->maskCache.find( TQString::number( pix->serialNumber() ), m ) )
return m;
m = KPixmapEffect::selectedPixmap( KPixmap(*pix), col );
- d->tqmaskCache.insert( TQString::number( pix->serialNumber() ), m );
+ d->maskCache.insert( TQString::number( pix->serialNumber() ), m );
return m;
}
@@ -485,7 +485,7 @@ void KIconViewItem::calcRect( const TQString& text_ )
KIconView *view = static_cast<KIconView *>(iconView());
TQRect itemIconRect = pixmapRect();
TQRect itemTextRect = textRect();
- TQRect tqitemRect = rect();
+ TQRect itemRect = rect();
int pw = 0;
int ph = 0;
@@ -507,9 +507,9 @@ void KIconViewItem::calcRect( const TQString& text_ )
itemIconRect.setWidth( pw );
#if 1 // FIXME
// There is a bug in Qt which prevents the item from being placed
// properly when the pixmapRect is not at the top of the tqitemRect, so we
// have to increase the height of the pixmapRect and leave it at the top
- // of the tqitemRect...
+ // of the itemRect...
if ( d && !d->m_pixmapSize.isNull() )
itemIconRect.setHeight( d->m_pixmapSize.height() + 2 );
else
@@ -574,8 +574,8 @@ void KIconViewItem::calcRect( const TQString& text_ )
h = itemTextRect.height() + itemIconRect.height() + 1;
}
- tqitemRect.setWidth( w );
- tqitemRect.setHeight( h );
+ itemRect.setWidth( w );
+ itemRect.setHeight( h );
int width = QMAX( w, TQApplication::globalStrut().width() ); // see TQIconViewItem::width()
int height = QMAX( h, TQApplication::globalStrut().height() ); // see TQIconViewItem::height()
itemTextRect = TQRect( ( width - itemTextRect.width() ) / 2, height - itemTextRect.height(),
@@ -597,8 +597,8 @@ void KIconViewItem::calcRect( const TQString& text_ )
h = QMAX( itemTextRect.height(), itemIconRect.height() );
w = itemTextRect.width() + itemIconRect.width() + 1;
- tqitemRect.setWidth( w );
- tqitemRect.setHeight( h );
+ itemRect.setWidth( w );
+ itemRect.setHeight( h );
int width = QMAX( w, TQApplication::globalStrut().width() ); // see TQIconViewItem::width()
int height = QMAX( h, TQApplication::globalStrut().height() ); // see TQIconViewItem::height()
@@ -621,8 +621,8 @@ void KIconViewItem::calcRect( const TQString& text_ )
setPixmapRect( itemIconRect );
if ( itemTextRect != textRect() )
setTextRect( itemTextRect );
- if ( tqitemRect != rect() )
- setItemRect( tqitemRect );
+ if ( itemRect != rect() )
+ setItemRect( itemRect );
// Done by setPixmapRect, setTextRect and setItemRect ! [and useless if no rect changed]
//view->updateItemContainer( this );
@@ -680,7 +680,7 @@ void KIconViewItem::paintPixmap( TQPainter *p, const TQColorGroup &cg )
#if 1 // FIXME
// Move the pixmap manually because the pixmapRect is at the
// top of the tqitemRect
// (won't be needed anymore in future versions of qt)
if ( d && !d->m_pixmapSize.isNull() )
{
@@ -507,9 +507,9 @@ void KIconViewItem::calcRect( const TQString& text_ )
#if 1 // FIXME
// There is a bug in Qt which prevents the item from being placed
- // properly when the pixmapRect is not at the top of the tqitemRect, so we
+ // properly when the pixmapRect is not at the top of the itemRect, so we
// have to increase the height of the pixmapRect and leave it at the top
@@ -680,7 +680,7 @@ void KIconViewItem::paintPixmap( TQPainter *p, const TQColorGroup &cg )
#if 1 // FIXME
// Move the pixmap manually because the pixmapRect is at the
- // top of the tqitemRect
+ // top of the itemRect
// (won't be needed anymore in future versions of qt)
if ( d && !d->m_pixmapSize.isNull() )